# Welcome to the API docs

This API documentation is automatically generated by mkdocstrings. It can be used with mkdocs serve, or built statically with mkdocs build. 

## Package Layout


    scores
        continuous      # Scores which relate to the estimates of quantities
        classification  # Scores which relate to the estimates or categories
        probability     # Scores which relate to estimates of probabilities
        spatial         # Scores which relate to (geo)spatial accuracy

## scores.continuous
::: scores.continuous

## scores.classification

## scores.probability.crps
::: scores.probability.crps

## scores.spatial